@@ -9,14 +9,12 @@ from anipy_cli.cli.menus import Menu
 from anipy_cli.cli.clis.base_cli import CliBase
 
 
-class DefaultCli(CliBase): 
+class DefaultCli(CliBase):
     def __init__(self, options: CliArgs, rpc_client=None):
         super().__init__(options, rpc_client)
 
         self.entry = Entry()
-        self.player = get_player(
-            self.rpc_client, self.options.optional_player
-        )
+        self.player = get_player(self.rpc_client, self.options.optional_player)
 
     def print_header(self):
         pass
@@ -24,7 +22,7 @@ class DefaultCli(CliBase):
     def take_input(self):
         inp = input("Search: ")
         user_query = query(inp, self.entry)
-        
+
         if user_query.get_links() == 0:
             self.exit("no search results")
 
@@ -38,11 +36,11 @@ class DefaultCli(CliBase):
 
     def show(self):
         self.player.play_title(self.entry)
-        
+
     def post(self):
         Menu(
             options=self.options,
             entry=self.entry,
             player=self.player,
-            rpc_client=self.rpc_client
+            rpc_client=self.rpc_client,
         ).run()
