@@ -5,7 +5,6 @@ from anipy_cli.config import Config
 class Vlc(SubProcessPlayerBase):
     def __init__(self, rpc_client=None):
         player_args_template = [
-            "vlc",
             "--http-referrer='{embed_url}'",
             "--meta-title='{media_title}'",
             "{stream_url}",
@@ -13,5 +12,7 @@ class Vlc(SubProcessPlayerBase):
         ]
 
         super().__init__(
-            rpc_client=rpc_client, player_args_template=player_args_template
+            rpc_client=rpc_client, 
+            player_args_template=player_args_template, 
+            player_exec="vlc",
         )
